aboutsummaryrefslogtreecommitdiffstats
path: root/crypto/des/des.h
diff options
context:
space:
mode:
authorRichard Levitte <levitte@openssl.org>2001-03-29 07:45:37 +0000
committerRichard Levitte <levitte@openssl.org>2001-03-29 07:45:37 +0000
commit080b8cadfa9a9c7655fb0dbd5e432b09d708ab3b (patch)
treed233e346f517c1eedaa0066c31380b8d225e0c07 /crypto/des/des.h
parent7cdd2aa128811724497b98d20dd06a2efca9c266 (diff)
downloadopenssl-080b8cadfa9a9c7655fb0dbd5e432b09d708ab3b.tar.gz
Since there has been reports of clashes between OpenSSL's
des_encrypt() and des_encrypt() defined on some systems (Solaris and Unixware and maybe others), we rename des_encrypt() to des_encrypt1(). This should have very little impact on external software unless someone has written a mode of DES, since that's all des_encrypt() is meant for.
Diffstat (limited to 'crypto/des/des.h')
-rw-r--r--crypto/des/des.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/crypto/des/des.h b/crypto/des/des.h
index dc627189b4..96222c30be 100644
--- a/crypto/des/des.h
+++ b/crypto/des/des.h
@@ -153,14 +153,14 @@ void des_ecb_encrypt(const_des_cblock *input,des_cblock *output,
Data is a pointer to 2 unsigned long's and ks is the
des_key_schedule to use. enc, is non zero specifies encryption,
zero if decryption. */
-void des_encrypt(DES_LONG *data,des_key_schedule ks, int enc);
+void des_encrypt1(DES_LONG *data,des_key_schedule ks, int enc);
-/* This functions is the same as des_encrypt() except that the DES
+/* This functions is the same as des_encrypt1() except that the DES
initial permutation (IP) and final permutation (FP) have been left
- out. As for des_encrypt(), you should not use this function.
+ out. As for des_encrypt1(), you should not use this function.
It is used by the routines in the library that implement triple DES.
IP() des_encrypt2() des_encrypt2() des_encrypt2() FP() is the same
- as des_encrypt() des_encrypt() des_encrypt() except faster :-). */
+ as des_encrypt1() des_encrypt1() des_encrypt1() except faster :-). */
void des_encrypt2(DES_LONG *data,des_key_schedule ks, int enc);
void des_encrypt3(DES_LONG *data, des_key_schedule ks1,